@@ -114,9 +114,16 @@ get_scope (GoaOAuth2Provider *provider)
 {
   return "wl.messenger,"
          "wl.offline_access,"
+         "wl.skydrive_update,"
          "wl.emails";
 }
 
+static guint
+get_credentials_generation (GoaProvider *provider)
+{
+  return 1;
+}
+
 static const gchar *
 get_client_id (GoaOAuth2Provider *provider)
 {
@@ -129,6 +136,12 @@ get_client_secret (GoaOAuth2Provider *provider)
   return NULL;
 }
 
+static const gchar *
+get_authentication_cookie (GoaOAuth2Provider *provider)
+{
+  return "MSNPPAuth";
+}
+
 /* ---------------------------------------------------------------------------------------------------- */
 
 static gchar *
@@ -231,20 +244,29 @@ build_object (GoaProvider         *provider,
               GoaObjectSkeleton   *object,
               GKeyFile            *key_file,
               const gchar         *group,
+              gboolean             just_added,
               GError             **error)
 {
+  GoaAccount *account;
   GoaChat *chat = NULL;
+  GoaDocuments *documents;
   gboolean chat_enabled;
+  gboolean documents_enabled;
   gboolean ret = FALSE;
 
+  account = NULL;
+
   /* Chain up */
   if (!GOA_PROVIDER_CLASS (goa_windows_live_provider_parent_class)->build_object (provider,
                                                                               object,
                                                                               key_file,
                                                                               group,
+                                                                              just_added,
                                                                               error))
     goto out;
 
+  account = goa_object_get_account (GOA_OBJECT (object));
+
   /* Chat */
   chat = goa_object_get_chat (GOA_OBJECT (object));
   chat_enabled = g_key_file_get_boolean (key_file, group, "ChatEnabled", NULL);
@@ -262,12 +284,46 @@ build_object (GoaProvider         *provider,
         goa_object_skeleton_set_chat (object, NULL);
     }
 
+  /* Documents */
+  documents = goa_object_get_documents (GOA_OBJECT (object));
+  documents_enabled = g_key_file_get_boolean (key_file, group, "DocumentsEnabled", NULL);
+
+  if (documents_enabled)
+    {
+      if (documents == NULL)
+        {
+          documents = goa_documents_skeleton_new ();
+          goa_object_skeleton_set_documents (object, documents);
+        }
+    }
+  else
+    {
+      if (documents != NULL)
+        goa_object_skeleton_set_documents (object, NULL);
+    }
+
+  if (just_added)
+    {
+      goa_account_set_chat_disabled (account, !chat_enabled);
+      goa_account_set_documents_disabled (account, !documents_enabled);
+
+      g_signal_connect (account,
+                        "notify::chat-disabled",
+                        G_CALLBACK (goa_util_account_notify_property_cb),
+                        "ChatEnabled");
+      g_signal_connect (account,
+                        "notify::documents-disabled",
+                        G_CALLBACK (goa_util_account_notify_property_cb),
+                        "DocumentsEnabled");
+    }
+
   ret = TRUE;
 
  out:
   if (chat != NULL)
     g_object_unref (chat);
-
+  if (account != NULL)
+    g_object_unref (account);
   return ret;
 }
 
@@ -284,13 +340,26 @@ show_account (GoaProvider         *provider,
               GoaClient           *client,
               GoaObject           *object,
               GtkBox              *vbox,
-              GtkTable            *table)
+              GtkGrid             *left,
+              GtkGrid             *right)
 {
   /* Chain up */
-  GOA_PROVIDER_CLASS (goa_windows_live_provider_parent_class)->show_account (provider, client, object, vbox, table);
+  GOA_PROVIDER_CLASS (goa_windows_live_provider_parent_class)->show_account (provider,
+                                                                             client,
+                                                                             object,
+                                                                             vbox,
+                                                                             left,
+                                                                             right);
 
-  goa_util_add_row_editable_label_from_keyfile (table, object, _("User Name"), "PresentationIdentity", FALSE);
-  goa_util_add_row_switch_from_keyfile (table, object, _("Chat"), "ChatEnabled");
+  goa_util_add_row_switch_from_keyfile_with_blurb (left, right, object,
+                                                   _("Use for"),
+                                                   "chat-disabled",
+                                                   _("Chat"));
+
+  goa_util_add_row_switch_from_keyfile_with_blurb (left, right, object,
+                                                   NULL,
+                                                   "documents-disabled",
+                                                   _("Documents"));
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -300,6 +369,7 @@ add_account_key_values (GoaOAuth2Provider *provider,
                         GVariantBuilder   *builder)
 {
   g_variant_builder_add (builder, "{ss}", "ChatEnabled", "true");
+  g_variant_builder_add (builder, "{ss}", "DocumentsEnabled", "true");
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -321,6 +391,7 @@ goa_windows_live_provider_class_init (GoaWindowsLiveProviderClass *klass)
   provider_class->get_provider_icon          = get_provider_icon;
   provider_class->build_object               = build_object;
   provider_class->show_account               = show_account;
+  provider_class->get_credentials_generation = get_credentials_generation;
 
   oauth2_class = GOA_OAUTH2_PROVIDER_CLASS (klass);
   oauth2_class->get_authorization_uri    = get_authorization_uri;
@@ -329,6 +400,7 @@ goa_windows_live_provider_class_init (GoaWindowsLiveProviderClass *klass)
   oauth2_class->get_scope                = get_scope;
   oauth2_class->get_client_id            = get_client_id;
   oauth2_class->get_client_secret        = get_client_secret;
+  oauth2_class->get_authentication_cookie = get_authentication_cookie;
   oauth2_class->get_identity_sync        = get_identity_sync;
   oauth2_class->get_use_external_browser = get_use_external_browser;
   oauth2_class->add_account_key_values   = add_account_key_values;
